@@ -8,9 +8,9 @@ OC.L10N.register(
     "We wanted to inform you that %s has published the calendar »%s«." : "Queremos informarte que %s ha publicado el calendario »%s«.",
     "Open »%s«" : "Abrir »%s«",
     "Cheers!" : "¡Saludos!",
+    "Calendar" : "Calendario",
     "Confirm" : "Confirmar",
     "Where:" : "Dónde:",
-    "Calendar" : "Calendario",
     "New event" : "Nuevo evento",
     "Today" : "Hoy",
     "Day" : "Día",
@@ -31,6 +31,7 @@ OC.L10N.register(
     "Share link" : "Compartir enlace",
     "can edit" : "puede editar",
     "Share with users or groups" : "Compartir con otros usuarios o grupos",
+    "Save" : "Guardar",
     "Filename" : "Nombre del archivo",
     "Cancel" : "Cancelar",
     "Automatic" : "Automático",
@@ -49,11 +50,12 @@ OC.L10N.register(
     "Friday" : "Viernes",
     "Saturday" : "Sábado",
     "Sunday" : "Domingo",
-    "Save" : "Guardar",
     "Update" : "Actualizar",
     "Your email address" : "Tu dirección de correo electrónico",
     "Notification" : "Notificación",
     "Email" : "Correo electrónico",
+    "Delete file" : "Borrar archivo",
+    "Choose a file to add as attachment" : "Selecciona el archivo a agregar como adjunto",
     "Unknown" : "Desconocido",
     "Accept" : "Aceptar",
     "Decline" : "Declinar",
@@ -66,6 +68,7 @@ OC.L10N.register(
     "available" : "disponible",
     "More" : "Más",
     "Global" : "Global",
+    "Subscribe" : "Suscribir",
     "Personal" : "Personal",
     "Details" : "Detalles",
     "Attendees" : "Asistentes",
@@ -75,8 +78,6 @@ OC.L10N.register(
     "Week {number} of {year}" : "Semana {number} de {year}",
     "Daily" : "Diariamente",
     "Weekly" : "Semanalmente",
-    "Prev" : "Prev",
-    "Next" : "Siguiente",
     "Other" : "Otro",
     "When shared show full event" : "Al compartir, mostrar el evento completo",
     "When shared show only busy" : "Al compartir, mostrar sólo como ocupado ",
