@@ -43,6 +43,7 @@ OC.L10N.register(
     "Share link" : "Холбоос хуваалцах",
     "can edit" : "засаж чадна",
     "Share with users or groups" : "Бусад хэрэглэгч, бүлэгт хуваалцах",
+    "Save" : "Хадгалах",
     "Filename" : "Файлын нэр",
     "Cancel" : "Цуцлах",
     "Actions" : "Үйл ажиллагаа",
@@ -58,7 +59,6 @@ OC.L10N.register(
     "Friday" : "баасан",
     "Saturday" : "бямба",
     "Sunday" : "ням гариг",
-    "Save" : "Хадгалах",
     "Update" : "Шинэчлэх",
     "Notification" : "Мэдэгдэл",
     "Email" : "Цахим шуудан",
@@ -74,6 +74,7 @@ OC.L10N.register(
     "after" : "дараа",
     "More" : "Дэлгэрэнгүй",
     "Global" : "Нийтийн",
+    "Subscribe" : "Захиалга",
     "Personal" : "Хувийн",
     "Details" : "Дэлгэрэнгүй",
     "Attendees" : "Оролцогчид",
@@ -81,7 +82,6 @@ OC.L10N.register(
     "Week {number} of {year}" : "{year} оны {number}-р долоо хоног ",
     "Daily" : "Өдөр бүр",
     "Weekly" : "Долоо хоног бүр",
-    "Next" : "дараагийх",
     "Other" : "Бусад",
     "When shared show full event" : "Түгээсэн тохиолдолд үйл явдлыг бүтнээр нь харуул",
     "When shared show only busy" : "Түгээсэн тохиолдолд зөвхөн завгүй гэж харуул",
